@@ -5,7 +5,7 @@ tv.coverperc <- function (db, obs, RelScale, tv_home, tvscale, quiet=FALSE, ...)
   }
   
   if(missing(tvscale)) {
-    print(list.files(file.path(tv_home, "Popup", tv.dict(db))))
+#    print(list.files(file.path(tv_home, "Popup", tv.dict(db))))
     tvscale <- read.dbf(file.path(tv_home, "Popup", tv.dict(db), "tvscale.dbf") )
   }
   tvscale <- tvscale[!is.na(tvscale$SCALE_NR),]
